@@ -85,7 +85,7 @@ async def ingl_init(payer_keypair: KeypairInput, validator_pubkey: PubkeyInput,
     # print(accounts)
     data = build_instruction(InstructionEnum.enum.Init(init_commission = init_commission, max_primary_stake = max_primary_stake, nft_holders_share = nft_holders_share, initial_redemption_fee = initial_redemption_fee, is_validator_id_switchable = is_validator_id_switchable, unit_backing = unit_backing, redemption_fee_duration = redemption_fee_duration, proposal_quorum = proposal_quorum, creator_royalties = creator_royalties, governance_expiration_time = governance_expiration_time, rarities = rarities, rarity_names = rarity_names, twitter_handle = twitter_handle, discord_invite = discord_invite, validator_name = validator_name, collection_uri = collection_uri, website = website, default_uri = default_uri, log_level = log_level))
     transaction = Transaction()
-    print(data)
+    # print(data)
     transaction.add(ComputeBudgetInstruction().set_compute_unit_limit(300_000, payer_keypair.pubkey))
     transaction.add(Instruction(accounts = accounts, program_id = get_program_id(), data = data))
    
